2024-10-17 Version: 4.1.4
- Update API ListNodes: update response param.


2024-09-29 Version: 4.1.3
- Update API CreateDISyncTask: update param TaskContent.
- Update API GetNode: update response param.


2024-09-18 Version: 4.1.2
- Update API GetRemind: update response param.


2024-09-03 Version: 4.1.1
- Update API GetFile: update response param.


2024-09-03 Version: 4.1.0
- Support API ListTables.
- Update API CreateFile: add param ApplyScheduleImmediately.
- Update API DeleteLineageRelation: add param RelationshipType.
- Update API GetFile: update response param.
- Update API UpdateFile: add param ApplyScheduleImmediately.


2024-07-31 Version: 4.0.0
- Support API ListClusterConfigs.
- Support API ListClusters.
- Support API UpdateClusterConfigs.
- Update API GetQualityRule: update response param.
- Update API QuerySensNodeInfo: add param RegionId.
- Update API QuerySensNodeInfo: delete param regionId.
- Update API UpdateDataSource: update param Content.


2024-06-07 Version: 3.5.0
- Support API ListMeasureData.


2024-06-07 Version: 3.4.1
- Generated python2 2020-05-18 for dataworks-public.

2024-06-04 Version: 3.4.0
- Support API DsgDesensPlanAddOrUpdate.
- Support API DsgDesensPlanDelete.
- Support API DsgDesensPlanQueryList.
- Support API DsgDesensPlanUpdateStatus.
- Support API DsgPlatformQueryProjectsAndSchemaFromMeta.
- Support API DsgQueryDefaultTemplates.
- Support API DsgSceneAddOrUpdateScene.
- Support API DsgSceneQuerySceneListByName.
- Support API DsgScenedDeleteScene.
- Support API DsgUserGroupAddOrUpdate.
- Support API DsgUserGroupDelete.
- Support API DsgUserGroupGetOdpsRoleGroups.
- Support API DsgUserGroupQueryList.
- Support API DsgUserGroupQueryUserList.
- Support API DsgWhiteListAddOrUpdate.
- Support API DsgWhiteListDeleteList.
- Support API DsgWhiteListQueryList.
- Update API CreateDIJob: update param ResourceSettings.
- Update API CreateQualityEntity: update response param.
- Update API CreateQualityRelativeNode: update response param.
- Update API DeleteQualityEntity: update response param.
- Update API DeleteQualityRelativeNode: update response param.
- Update API GetDIJob: update response param.
- Update API GetNode: update response param.
- Update API GetNodeChildren: update response param.
- Update API GetNodeParents: update response param.
- Update API ListNodes: update response param.
- Update API ListQualityResultsByRule: update response param.
- Update API UpdateDIJob: update param ResourceSettings.


2024-04-24 Version: 3.3.0
- Support API AddRecognizeRule.
- Support API DeleteRecognizeRule.
- Support API DsgRunSensIdentify.
- Support API DsgStopSensIdentify.
- Support API EditRecognizeRule.
- Support API QueryDefaultTemplate.
- Support API QueryRecognizeDataByRuleType.
- Support API QueryRecognizeRuleDetail.
- Support API QueryRecognizeRulesType.
- Support API QuerySensClassification.
- Support API QuerySensLevel.
- Support API QuerySensNodeInfo.
- Update API SubmitDataServiceApi: update response param.


2024-04-17 Version: 3.2.0
- Support API DsgQuerySensResult.
- Update API CreateFile: update param DependentType.
- Update API ListInstances: update param NodeId.
- Update API UpdateFile: update param DependentType.


2024-03-29 Version: 3.1.0
- Support API CreateProject.
- Support API GetAlertMessage.
- Update API CreateDIJob: update param JobSettings.
- Update API CreateDIJob: update response param.
- Update API CreateQualityEntity: update param ProjectId.
- Update API DeleteQualityEntity: update param ProjectId.
- Update API DeleteQualityRule: update param ProjectId.
- Update API GetDIJob: update response param.
- Update API GetQualityEntity: update param ProjectId.
- Update API GetQualityFollower: update param ProjectId.
- Update API ListNodes: add param SchedulerType.
- Update API ListQualityResultsByEntity: update param EntityId.
- Update API ListQualityResultsByEntity: update param ProjectId.
- Update API ListQualityResultsByEntity: update response param.
- Update API ListQualityResultsByRule: update param ProjectId.
- Update API ListQualityRules: update param ProjectId.
- Update API ListQualityRules: update response param.
- Update API RunCycleDagNodes: add param AlertNoticeType.
- Update API RunCycleDagNodes: add param AlertType.
- Update API RunCycleDagNodes: add param ConcurrentRuns.
- Update API UpdateDIJob: update param JobSettings.
- Update API UpdateDIJob: update response param.
- Update API UpdateQualityRule: update param ProjectId.


2024-02-29 Version: 3.0.0
- Support API GetAlertMessage.
- Update API CreateDIJob: update param JobSettings.
- Update API CreateDIJob: update response param.
- Update API CreateQualityEntity: update param ProjectId.
- Update API DeleteQualityEntity: update param ProjectId.
- Update API DeleteQualityRule: update param ProjectId.
- Update API GetDIJob: update response param.
- Update API GetQualityEntity: update param ProjectId.
- Update API GetQualityFollower: update param ProjectId.
- Update API ListNodes: add param SchedulerType.
- Update API ListQualityResultsByEntity: update param EntityId.
- Update API ListQualityResultsByEntity: update param ProjectId.
- Update API ListQualityResultsByEntity: update response param.
- Update API ListQualityResultsByRule: update param ProjectId.
- Update API ListQualityRules: update param ProjectId.
- Update API ListQualityRules: update response param.
- Update API RunCycleDagNodes: add param AlertNoticeType.
- Update API RunCycleDagNodes: add param AlertType.
- Update API RunCycleDagNodes: add param ConcurrentRuns.
- Update API UpdateDIJob: update param JobSettings.
- Update API UpdateDIJob: update response param.
- Update API UpdateQualityRule: update param ProjectId.


2023-12-11 Version: 2.0.0
- Generated python2 2020-05-18 for dataworks-public.

2023-11-23 Version: 1.5.4
- Generated python2 2020-05-18 for dataworks-public.

2023-11-15 Version: 1.5.3
- Generated python2 2020-05-18 for dataworks-public.

2023-10-10 Version: 1.5.2
- Generated python2 2020-05-18 for dataworks-public.

2023-10-09 Version: 1.5.1
- Generated python2 2020-05-18 for dataworks-public.

2023-09-25 Version: 1.5.0
- Support DIJob and DIAlarmRule related APIs.

2023-09-19 Version: 1.4.0
- Generated python2 2020-05-18 for dataworks-public.

2023-08-10 Version: 1.3.0
- Generated python2 2020-05-18 for dataworks-public.

2023-07-25 Version: 1.2.12
- Generated python2 2020-05-18 for dataworks-public.

2023-07-17 Version: 1.2.11
- Generated python2 2020-05-18 for dataworks-public.

2023-06-12 Version: 1.2.10
- Generated python2 2020-05-18 for dataworks-public.

2023-06-05 Version: 1.2.9
- Generated python2 2020-05-18 for dataworks-public.

2023-03-31 Version: 1.2.8
- Generated python2 2020-05-18 for dataworks-public.

2023-03-16 Version: 1.2.7
- Generated python2 2020-05-18 for dataworks-public.

2023-03-08 Version: 1.2.6
- Generated python2 2020-05-18 for dataworks-public.

2023-03-07 Version: 1.2.5
- Generated python2 2020-05-18 for dataworks-public.

2023-03-07 Version: 1.2.4
- Generated python2 2020-05-18 for dataworks-public.

2023-03-02 Version: 1.2.3
- Generated python2 2020-05-18 for dataworks-public.

2023-03-02 Version: 1.2.2
- Generated python2 2020-05-18 for dataworks-public.

2023-02-09 Version: 1.2.1
- Generated python2 2020-05-18 for dataworks-public.

2023-01-13 Version: 1.2.0
- Generated python2 2020-05-18 for dataworks-public.

2023-01-05 Version: 1.1.23
- Generated python2 2020-05-18 for dataworks-public.

2022-12-23 Version: 1.1.22
- Generated python2 2020-05-18 for dataworks-public.

2022-12-22 Version: 1.1.21
- Generated python2 2020-05-18 for dataworks-public.

2022-12-16 Version: 1.1.20
- Generated python2 2020-05-18 for dataworks-public.

2022-12-02 Version: 1.1.19
- Generated python2 2020-05-18 for dataworks-public.

2022-12-02 Version: 1.1.18
- Generated python2 2020-05-18 for dataworks-public.

2022-11-16 Version: 1.1.17
- Generated python2 2020-05-18 for dataworks-public.

2022-10-13 Version: 1.1.16
- Generated python2 2020-05-18 for dataworks-public.

2022-08-31 Version: 1.1.15
- Generated python2 2020-05-18 for dataworks-public.

2022-08-11 Version: 1.1.14
- Generated python2 2020-05-18 for dataworks-public.

2022-07-20 Version: 1.1.13
- Generated python2 2020-05-18 for dataworks-public.

2022-07-19 Version: 1.1.12
- Generated python2 2020-05-18 for dataworks-public.

2022-05-30 Version: 1.1.11
- Generated python2 2020-05-18 for dataworks-public.

2022-05-10 Version: 1.1.10
- Generated python2 2020-05-18 for dataworks-public.

2022-05-07 Version: 1.1.9
- Generated python2 2020-05-18 for dataworks-public.

2022-04-25 Version: 1.1.8
- Generated python2 2020-05-18 for dataworks-public.

2022-04-19 Version: 1.1.7
- Generated python2 2020-05-18 for dataworks-public.

2022-04-07 Version: 1.1.6
- Generated python2 2020-05-18 for dataworks-public.

2022-03-21 Version: 1.1.5
- Generated python2 2020-05-18 for dataworks-public.

2022-02-28 Version: 1.1.4
- Generated python2 2020-05-18 for dataworks-public.

2021-12-06 Version: 1.1.3
- Generated python2 2020-05-18 for dataworks-public.

2021-10-21 Version: 1.1.2
- Generated python2 2020-05-18 for dataworks-public.

2021-10-21 Version: 1.1.1
- Generated python2 2020-05-18 for dataworks-public.

2021-09-10 Version: 1.1.0
- Generated python2 2020-05-18 for dataworks-public.

2021-08-20 Version: 1.0.1
- Generated python2 2020-05-18 for dataworks-public.

2021-05-20 Version: 1.0.0
- Generated python2 2020-05-18 for dataworks-public.

